@@ -357,7 +357,7 @@
 /* #undef SDL_HAPTIC_DINPUT */
 /* #undef SDL_HAPTIC_XINPUT */
 /* #undef SDL_HAPTIC_ANDROID */
-/* #undef SDL_LIBUSB_DYNAMIC */
+#define SDL_LIBUSB_DYNAMIC "libusb-1.0.so.0"
 
 /* Enable various sensor drivers */
 /* #undef SDL_SENSOR_ANDROID */
